@@ -26,7 +26,7 @@ class User(db.BaseModel):
 
 
 class JournalEntity(db.BaseModel):
-    local_user = pw.ForeignKeyField(User, related_name='journals')
+    local_user = pw.ForeignKeyField(User, backref='journals')
     version = pw.IntegerField()
     uid = pw.CharField(null=False, index=True)
     owner = pw.CharField(null=True)
@@ -45,7 +45,7 @@ class JournalEntity(db.BaseModel):
 
 
 class EntryEntity(db.BaseModel):
-    journal = pw.ForeignKeyField(JournalEntity, related_name='entries')
+    journal = pw.ForeignKeyField(JournalEntity, backref='entries')
     uid = pw.CharField(null=False, index=True)
     content = pw.BlobField()
     new = pw.BooleanField(null=False, default=False)
@@ -58,6 +58,6 @@ class EntryEntity(db.BaseModel):
 
 
 class UserInfo(db.BaseModel):
-    user = pw.ForeignKeyField(User, primary_key=True, related_name='user_info')
+    user = pw.ForeignKeyField(User, primary_key=True, backref='user_info')
     pubkey = pw.BlobField(null=False)
     content = pw.BlobField(null=False)
